==> galileo-1.26.0.tar.gz: galileo-1.26.0/src/galileo/resources/api/experiment_tags/update_tag_for_experiment_projects_project_id_experiments_experiment_id_tags_tag_id_put.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.http_validation_error import HTTPValidationError
from ...models.run_tag_create_request import RunTagCreateRequest
from ...models.run_tag_db import RunTagDB
from ...types import Response


def _get_kwargs(project_id: str, experiment_id: str, tag_id: str, *, body: RunTagCreateRequest) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.PUT,
        "return_raw_response": True,
        "path": f"/projects/{project_id}/experiments/{experiment_id}/tags/{tag_id}",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(*, client: ApiClient, response: httpx.Response) -> Optional[Union[HTTPValidationError, RunTagDB]]:
    if response.status_code == 200:
        return RunTagDB.from_dict(response.json())

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(*, client: ApiClient, response: httpx.Response) -> Response[Union[HTTPValidationError, RunTagDB]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, experiment_id: str, tag_id: str, *, client: ApiClient, body: RunTagCreateRequest
) -> Response[Union[HTTPValidationError, RunTagDB]]:
    """Update Tag For Experiment

     Sets or updates a tag for an experiment.

    Args:
        project_id (str):
        experiment_id (str):
        tag_id (str):
        body (RunTagCreateRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, RunTagDB]]
    """

    kwargs = _get_kwargs(project_id=project_id, experiment_id=experiment_id, tag_id=tag_id, body=body)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, experiment_id: str, tag_id: str, *, client: ApiClient, body: RunTagCreateRequest
) -> Optional[Union[HTTPValidationError, RunTagDB]]:
    """Update Tag For Experiment

     Sets or updates a tag for an experiment.

    Args:
        project_id (str):
        experiment_id (str):
        tag_id (str):
        body (RunTagCreateRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, RunTagDB]
    """

    return sync_detailed(
        project_id=project_id, experiment_id=experiment_id, tag_id=tag_id, client=client, body=body
    ).parsed


async def asyncio_detailed(
    project_id: str, experiment_id: str, tag_id: str, *, client: ApiClient, body: RunTagCreateRequest
) -> Response[Union[HTTPValidationError, RunTagDB]]:
    """Update Tag For Experiment

     Sets or updates a tag for an experiment.

    Args:
        project_id (str):
        experiment_id (str):
        tag_id (str):
        body (RunTagCreateRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, RunTagDB]]
    """

    kwargs = _get_kwargs(project_id=project_id, experiment_id=experiment_id, tag_id=tag_id, body=body)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, experiment_id: str, tag_id: str, *, client: ApiClient, body: RunTagCreateRequest
) -> Optional[Union[HTTPValidationError, RunTagDB]]:
    """Update Tag For Experiment

     Sets or updates a tag for an experiment.

    Args:
        project_id (str):
        experiment_id (str):
        tag_id (str):
        body (RunTagCreateRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, RunTagDB]
    """

    return (
        await asyncio_detailed(
            project_id=project_id, experiment_id=experiment_id, tag_id=tag_id, client=client, body=body
        )
    ).parsed

==> galileo-1.28.0.tar.gz: galileo-1.28.0/src/galileo/resources/api/experiment_tags/update_tag_for_experiment_projects_project_id_experiments_experiment_id_tags_tag_id_put.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.http_validation_error import HTTPValidationError
from ...models.run_tag_create_request import RunTagCreateRequest
from ...models.run_tag_db import RunTagDB
from ...types import Response


def _get_kwargs(project_id: str, experiment_id: str, tag_id: str, *, body: RunTagCreateRequest) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.PUT,
        "return_raw_response": True,
        "path": f"/projects/{project_id}/experiments/{experiment_id}/tags/{tag_id}",
    }

    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(*, client: ApiClient, response: httpx.Response) -> Optional[Union[HTTPValidationError, RunTagDB]]:
    if response.status_code == 200:
        return RunTagDB.from_dict(response.json())

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(*, client: ApiClient, response: httpx.Response) -> Response[Union[HTTPValidationError, RunTagDB]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str, experiment_id: str, tag_id: str, *, client: ApiClient, body: RunTagCreateRequest
) -> Response[Union[HTTPValidationError, RunTagDB]]:
    """Update Tag For Experiment.

     Sets or updates a tag for an experiment.

    Args:
        project_id (str):
        experiment_id (str):
        tag_id (str):
        body (RunTagCreateRequest):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[HTTPValidationError, RunTagDB]]
    """
    kwargs = _get_kwargs(project_id=project_id, experiment_id=experiment_id, tag_id=tag_id, body=body)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    project_id: str, experiment_id: str, tag_id: str, *, client: ApiClient, body: RunTagCreateRequest
) -> Optional[Union[HTTPValidationError, RunTagDB]]:
    """Update Tag For Experiment.

     Sets or updates a tag for an experiment.

    Args:
        project_id (str):
        experiment_id (str):
        tag_id (str):
        body (RunTagCreateRequest):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[HTTPValidationError, RunTagDB]
    """
    return sync_detailed(
        project_id=project_id, experiment_id=experiment_id, tag_id=tag_id, client=client, body=body
    ).parsed


async def asyncio_detailed(
    project_id: str, experiment_id: str, tag_id: str, *, client: ApiClient, body: RunTagCreateRequest
) -> Response[Union[HTTPValidationError, RunTagDB]]:
    """Update Tag For Experiment.

     Sets or updates a tag for an experiment.

    Args:
        project_id (str):
        experiment_id (str):
        tag_id (str):
        body (RunTagCreateRequest):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Response[Union[HTTPValidationError, RunTagDB]]
    """
    kwargs = _get_kwargs(project_id=project_id, experiment_id=experiment_id, tag_id=tag_id, body=body)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str, experiment_id: str, tag_id: str, *, client: ApiClient, body: RunTagCreateRequest
) -> Optional[Union[HTTPValidationError, RunTagDB]]:
    """Update Tag For Experiment.

     Sets or updates a tag for an experiment.

    Args:
        project_id (str):
        experiment_id (str):
        tag_id (str):
        body (RunTagCreateRequest):

    Raises
    ------
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns
    -------
        Union[HTTPValidationError, RunTagDB]
    """
    return (
        await asyncio_detailed(
            project_id=project_id, experiment_id=experiment_id, tag_id=tag_id, client=client, body=body
        )
    ).parsed
